@@ -8,7 +8,7 @@ use nom::{
         streaming::none_of,
     },
     combinator::{eof, map, opt, peek, rest, success},
-    multi::many1,
+    multi::{many1, separated_list1},
     sequence::{delimited, pair, preceded, separated_pair, terminated, tuple},
 };
 use std::fmt::Display;
@@ -31,11 +31,13 @@ pub enum EventData<'a> {
     Author(&'a str),
     /// Define a subcommand, e.g. `@cmd A sub command`
     Cmd(&'a str),
-    /// Define a arguement
+    /// Define alias for a subcommand, e.g. `@alias t,tst`
+    Aliases(Vec<&'a str>),
+    /// Define a argument
     Arg(ArgData<'a>),
     /// A shell function. e.g `function cmd()` or `cmd()`
     Func(&'a str),
-    /// Palaceholder for unknown or invalid tag
+    /// Placeholder for unknown or invalid tag
     Unknown(&'a str),
 }
 
@@ -87,43 +89,14 @@ impl<'a> Display for ArgData<'a> {
                 if let Some(s) = self.short {
                     segments.push(format!("-{}", s));
                 }
-                let mut name = self.name.to_string();
-                if let Some(choices) = &self.choices {
-                    let mut prefix = String::new();
-                    if self.default.is_some() {
-                        prefix.push('=');
-                    }
-                    let values: Vec<String> = choices
-                        .iter()
-                        .map(|value| {
-                            if value.chars().any(is_terminate_char_choice_value) {
-                                format!("\"{}\"", value)
-                            } else {
-                                value.to_string()
-                            }
-                        })
-                        .collect();
-                    name.push_str(&format!("[{}{}]", prefix, values.join("|")))
-                } else if let Some(default) = self.default {
-                    let value = if default.chars().any(is_terminate_char_default_value) {
-                        format!("\"{}\"", default)
-                    } else {
-                        default.to_string()
-                    };
-                    name.push_str(&format!("={}", value));
-                } else if let Some(c) = self.name_suffix() {
-                    name.push(c)
-                }
+                let name = self.name_data();
                 segments.push(format!("--{}", name));
                 if let Some(value_name) = self.value_name {
                     segments.push(format!("<{}>", value_name));
                 }
             }
             ArgKind::Positional => {
-                let mut name = self.name.to_string();
-                if let Some(c) = self.name_suffix() {
-                    name.push(c)
-                }
+                let name = self.name_data();
                 segments.push(name);
             }
         }
@@ -151,6 +124,36 @@ impl<'a> ArgData<'a> {
     pub fn is_positional(&self) -> bool {
         self.kind == ArgKind::Positional
     }
+    fn name_data(&self) -> String {
+        let mut name = self.name.to_string();
+        if let Some(choices) = &self.choices {
+            let mut prefix = String::new();
+            if self.default.is_some() {
+                prefix.push('=');
+            }
+            let values: Vec<String> = choices
+                .iter()
+                .map(|value| {
+                    if value.chars().any(is_terminate_char_choice_value) {
+                        format!("\"{}\"", value)
+                    } else {
+                        value.to_string()
+                    }
+                })
+                .collect();
+            name.push_str(&format!("[{}{}]", prefix, values.join("|")))
+        } else if let Some(default) = self.default {
+            let value = if default.chars().any(is_terminate_char_default_value) {
+                format!("\"{}\"", default)
+            } else {
+                default.to_string()
+            };
+            name.push_str(&format!("={}", value));
+        } else if let Some(c) = self.name_suffix() {
+            name.push(c)
+        }
+        name
+    }
     fn name_suffix(&self) -> Option<char> {
         if self.multiple {
             return Some(match self.required {
@@ -214,7 +217,12 @@ fn parse_fn_no_keyword(input: &str) -> nom::IResult<&str, &str> {
 fn parse_tag(input: &str) -> nom::IResult<&str, Option<EventData>> {
     preceded(
         tuple((many1(char('#')), space0, char('@'))),
-        alt((parse_tag_text, parse_tag_arg, parse_tag_unknown)),
+        alt((
+            parse_tag_text,
+            parse_tag_arg,
+            parse_tag_alias,
+            parse_tag_unknown,
+        )),
     )(input)
 }
 
@@ -249,6 +257,18 @@ fn parse_tag_arg(input: &str) -> nom::IResult<&str, Option<EventData>> {
     preceded(check, alt((arg, success(None))))(input)
 }
 
+fn parse_tag_alias(input: &str) -> nom::IResult<&str, Option<EventData>> {
+    map(
+        pair(tag("alias"), preceded(space1, parse_name_list)),
+        |(tag, list)| {
+            Some(match tag {
+                "alias" => EventData::Aliases(list),
+                _ => unreachable!(),
+            })
+        },
+    )(input)
+}
+
 fn parse_tag_unknown(input: &str) -> nom::IResult<&str, Option<EventData>> {
     map(parse_name, |v| Some(EventData::Unknown(v)))(input)
 }
@@ -278,13 +298,16 @@ fn parse_option_arg(input: &str) -> nom::IResult<&str, ArgData> {
 
 // Parse `@option`, positional only
 fn parse_positional_arg(input: &str) -> nom::IResult<&str, ArgData> {
-    map(pair(parse_arg_mark, parse_tail), |(mut arg, summary)| {
-        arg.kind = ArgKind::Positional;
-        if !summary.is_empty() {
-            arg.summary = Some(summary);
-        }
-        arg
-    })(input)
+    map(
+        pair(alt((parse_arg_choices, parse_arg_mark)), parse_tail),
+        |(mut arg, summary)| {
+            arg.kind = ArgKind::Positional;
+            if !summary.is_empty() {
+                arg.summary = Some(summary);
+            }
+            arg
+        },
+    )(input)
 }
 
 // Parse `@flag`
@@ -401,6 +424,10 @@ fn parse_tail(input: &str) -> nom::IResult<&str, &str> {
     ))(input)
 }
 
+fn parse_name_list(input: &str) -> nom::IResult<&str, Vec<&str>> {
+    separated_list1(char(','), delimited(space0, parse_name, space0))(input)
+}
+
 fn parse_name(input: &str) -> nom::IResult<&str, &str> {
     take_while(|c: char| c.is_ascii_alphanumeric() || c == '_' || c == '-')(input)
 }
@@ -461,7 +488,7 @@ mod tests {
                 }
             );
         };
-        ($comment:literal, $kind:ident, $text:literal) => {
+        ($comment:literal, $kind:ident, $text:expr) => {
             assert_eq!(
                 parse_line($comment).unwrap().1,
                 Some(Some(EventData::$kind($text)))
@@ -541,6 +568,8 @@ mod tests {
         assert_parse_positional_arg!("foo!");
         assert_parse_positional_arg!("foo+");
         assert_parse_positional_arg!("foo*");
+        assert_parse_positional_arg!("foo[a|b]");
+        assert_parse_positional_arg!("foo[=a|b]");
     }
 
     #[test]
@@ -549,6 +578,8 @@ mod tests {
         assert_token!("# @version 1.0.0", Version, "1.0.0");
         assert_token!("# @author Somebody", Author, "Somebody");
         assert_token!("# @cmd A subcommand", Cmd, "A subcommand");
+        assert_token!("# @alias tst", Aliases, vec!["tst"]);
+        assert_token!("# @alias t,tst", Aliases, vec!["t", "tst"]);
         assert_token!("# @flag -f --foo", Arg);
         assert_token!("# @option -f --foo", Arg);
         assert_token!("# @arg foo", Arg);
